@@ -26,9 +26,12 @@
 #ifndef SHGFP_TYPE_CURRENT
 #define SHGFP_TYPE_CURRENT 0
 #endif
+#else
+#include <sys/statvfs.h>
+#include <errno.h>
 #endif
 
-CFileSystem* CFileSystem::singleton = NULL;
+static CFileSystem* singleton = NULL;
 
 FILE* CFileSystem::propen(const std::string& filename,
 			  const std::string& mode) const
@@ -216,8 +219,9 @@ void CFileSystem::Shutdown()
 	tmpFileSystem = NULL;
 }
 
-const std::string& CFileSystem::getSpringDir()
+const std::string CFileSystem::getSpringDir()
 {
+	assert(!springdir.empty());
 	if (springdir.empty())
 		(setWritePath(""));
 	return springdir;
@@ -713,3 +717,29 @@ std::string CFileSystem::EscapeFilename(const std::string& str)
 	}
 	return s;
 }
+
+unsigned long CFileSystem::getMBsFree(const std::string& path)
+{
+#ifdef WIN32
+	ULARGE_INTEGER freespace;
+	BOOL res = GetDiskFreeSpaceEx(s2ws(path).c_str(), &freespace, nullptr, nullptr);
+	if (!res) {
+		LOG_ERROR("Error getting free disk space on %s: %d", path.c_str(), GetLastError());
+		return 0;
+	}
+	return freespace.QuadPart / (1024 * 1024);
+#else
+	struct statvfs st;
+	const int ret = statvfs(path.c_str(), &st);
+	if (ret != 0) {
+		const char *errstr = strerror(errno);
+		LOG_ERROR("Error getting free disk space on %s: %s", path.c_str(), errstr);
+		return 0;
+	}
+	if (st.f_frsize) {
+		return ((uint64_t)st.f_frsize * st.f_bavail) / (1024 * 1024);
+	}
+	return ((uint64_t)st.f_bsize * st.f_bavail) / (1024 * 1024);
+#endif
+}
+
