@@ -66,6 +66,7 @@ SLCONFIG("/General/LastUpdateCheck", 0L, "Last time springlobby checked for an u
 SLCONFIG("/GUI/StartTab", (long)MainWindow::PAGE_SINGLE, "which tab to show on startup");
 SLCONFIG("/Chat/BroadcastEverywhere", true, "setting to spam the server messages in all channels");
 SLCONFIG("/Server/Autoconnect", false, "Connect to server on startup");
+SLCONFIG("/Server/TLS", false, "Use encrypted connection to the lobby server");
 
 
 static unsigned int s_reconnect_delay_ms = 6 * 1000; //initial reconnect delay
@@ -319,10 +320,6 @@ void Ui::OnDisconnected(IServer& server, bool wasonline)
 	if (m_main_win == 0)
 		return;
 	slLogDebugFunc("");
-	if (!&server) {
-		wxLogError(_T("WTF got null reference!!!"));
-		return;
-	}
 
 	mw().GetJoinTab().OnDisconnected();
 	mw().GetBattleListTab().OnDisconnected();
@@ -592,10 +589,7 @@ void Ui::OnBattleInfoUpdated(IBattle& battle, const wxString& Tag)
 		return;
 	mw().GetBattleListTab().UpdateBattle(battle);
 	if (mw().GetJoinTab().GetCurrentBattle() == &battle) {
-		if (Tag.IsEmpty())
-			mw().GetJoinTab().UpdateCurrentBattle();
-		else
-			mw().GetJoinTab().UpdateCurrentBattle(Tag);
+		mw().GetJoinTab().UpdateCurrentBattle(Tag);
 	}
 }
 
@@ -968,3 +962,19 @@ bool Ui::NeedsDownload(const IBattle* battle, bool uiprompt, DownloadEnum::Categ
 
 	return true;
 }
+
+void Ui::OnInvalidFingerprintReceived(const std::string& fingerprint, const std::string& expected_fingerprint)
+{
+	int answer = wxCANCEL;
+	if (expected_fingerprint.empty()) {
+		answer = customMessageBox(SL_MAIN_ICON, _("The certificate by the server is unkown. Do you want to trust it? Please verify the fingerprint:\n") + TowxString(fingerprint)  , _("Unknown Certificate"), wxYES_NO | wxCANCEL);
+	} else {
+		answer = customMessageBox(SL_MAIN_ICON, _("The certificate by the server is invalid! Maybe there is a MITM ongoing. Do you want ignore this warning?:\n") + TowxString(fingerprint)  , _("Unknown Certificate"), wxYES_NO | wxCANCEL);
+	}
+	if (answer != wxYES) {
+		return;
+	}
+
+	sett().SetServerFingerprint(m_serv->GetServerName(), fingerprint);
+	sett().SaveSettings();
+}
