@@ -403,6 +403,7 @@ void ServerEvents::OnBattleInfoUpdated(int battleid, int spectators, bool locked
 
 		ui().OnBattleInfoUpdated(battle, wxEmptyString);
 	} catch (assert_exception) {
+		wxLogWarning("Exception in OnBattleInfoUpdated");
 	}
 }
 
@@ -553,6 +554,7 @@ void ServerEvents::OnBattleInfoUpdated(int battleid)
 		IBattle& battle = m_serv.GetBattle(battleid);
 		ui().OnBattleInfoUpdated(battle, wxEmptyString);
 	} catch (assert_exception) {
+		wxLogWarning("Exception in OnBattleInfoUpdated(%d)", battleid);
 	}
 }
 
@@ -576,6 +578,7 @@ void ServerEvents::OnBattleDisableUnit(int battleid, const std::string& unitname
 	try {
 		IBattle& battle = m_serv.GetBattle(battleid);
 		battle.RestrictUnit(unitname, count);
+		wxLogDebug("OnBattleDisableUnit %d %s %d", battleid, unitname.c_str(), count);
 	} catch (assert_exception) {
 	}
 }
@@ -775,7 +778,6 @@ void ServerEvents::OnBattleAddBot(int battleid, const std::string& nick, UserBat
 		IBattle& battle = m_serv.GetBattle(battleid);
 		battle.OnBotAdded(nick, status);
 		User& bot = battle.GetUser(nick);
-		ASSERT_LOGIC(&bot != 0, "Bot null after add.");
 		ui().OnUserJoinedBattle(battle, bot);
 	} catch (assert_exception) {
 	}
@@ -900,7 +902,7 @@ void ServerEvents::OnKickedFromBattle()
 void ServerEvents::OnRedirect(const std::string& address, unsigned int port, const std::string& CurrentNick, const std::string& CurrentPassword)
 {
 	const std::string name = stdprintf("%s:%d", address.c_str(), port);
-	sett().SetServer(name, TowxString(address), port);
+	sett().SetServer(name, TowxString(address), port, "");
 	//TODO: Rework this. Server calls it`s own method through another object!
 	ServerManager::Instance()->DoConnectToServer(name, CurrentNick, CurrentPassword);
 }
@@ -999,3 +1001,10 @@ void ServerEvents::OnLoginDenied(const std::string& reason)
 {
 	ui().OnLoginDenied(reason);
 }
+
+void ServerEvents::OnInvalidFingerprintReceived(const std::string& fingerprint, const std::string& expected_fingerprint)
+{
+	ui().OnInvalidFingerprintReceived(fingerprint, expected_fingerprint);
+}
+
+
