@@ -35,7 +35,6 @@ lsl/networking/tasserver.cpp
 #include "utils/version.h"
 #include <lslutils/misc.h>
 
-
 SLCONFIG("/Server/ExitMessage", "Using http://springlobby.info/", "Message which is send when leaving server");
 
 // times in milliseconds
@@ -77,6 +76,7 @@ TASServer::TASServer()
     , m_server_lanmode(false)
     , m_account_id_count(0)
     , m_do_finalize_join_battle(false)
+    , m_do_register(false)
     , m_finalize_join_battle_id(-1)
 {
 	m_se = new ServerEvents(*this);
@@ -325,7 +325,7 @@ bool TASServer::IsOnline() const
 void TASServer::Register(const ServerLoginInfo& server)
 {
 	Connect(server);
-	SendCmd("REGISTER", server.username + std::string(" ") + GetPasswordHash(server.password));
+	m_do_register = true;
 }
 
 
@@ -399,7 +399,6 @@ void TASServer::RequestChannels()
 void TASServer::AcceptAgreement()
 {
 	SendCmd("CONFIRMAGREEMENT");
-	Login();
 }
 
 
@@ -532,12 +531,28 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 	UserBattleStatus bstatus;
 
 	if (cmd == "TASSERVER") {
-		m_ser_ver = GetIntParam(params);
-		const std::string supported_spring_version = GetWordParam(params);
-		m_nat_helper_port = (unsigned long)GetIntParam(params);
-		const bool lanmode = GetBoolParam(params);
-		m_server_lanmode = lanmode;
-		m_se->OnConnected(m_serverinfo.description, "", (m_ser_ver > 0), supported_spring_version, lanmode);
+#ifdef SSL_SUPPORT
+		if (!m_sock->IsTLS() && sett().IsServerTLS(GetServerName()) ) {
+			SendCmd("STLS", "");
+		} else {
+#endif
+			m_ser_ver = GetIntParam(params);
+			m_supported_spring_version = GetWordParam(params);
+			m_nat_helper_port = (unsigned long)GetIntParam(params);
+			m_server_lanmode = GetBoolParam(params);
+
+			if (m_do_register) {
+				SendCmd("REGISTER", m_serverinfo.username + std::string(" ") + GetPasswordHash(m_serverinfo.password));
+			} else {
+				m_se->OnConnected(m_serverinfo.description, "", true, m_supported_spring_version, m_server_lanmode);
+			}
+#ifdef SSL_SUPPORT
+		}
+#endif
+	} else if (cmd == "OK") {
+		if (!m_sock->IsTLS() && sett().IsServerTLS(GetServerName()) ) {
+			m_sock->StartTLS(sett().GetServerFingerprint(GetServerName()));
+		}
 	} else if (cmd == "ACCEPTED") {
 		SetUsername(params);
 		m_se->OnLogin();
@@ -934,7 +949,9 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 		const std::string scriptpw = GetWordParam(params);
 		m_se->OnForceJoinBattle(battleID, scriptpw);
 	} else if (cmd == "REGISTRATIONACCEPTED") {
+		m_do_register = false;
 		m_se->RegistrationAccepted(GetUserName(), GetPassword());
+		m_se->OnConnected(m_serverinfo.description, "", true, m_supported_spring_version, m_server_lanmode);
 	} else if (cmd == "REGISTRATIONDENIED") {
 		m_se->RegistrationDenied(params);
 	} else if (cmd == "LISTSUBSCRIPTION") {
@@ -983,7 +1000,7 @@ void TASServer::SendCmd(const std::string& command, const std::string& param, bo
 	else
 		msg = stdprintf("#%d %s %s", m_last_id, command.c_str(), param.c_str());
 	const bool send_success = m_sock->Send(msg + std::string("\n"));
-	if ((command == "LOGIN") || command == "CHANGEPASSWORD") {
+	if ((command == "LOGIN") || command == "CHANGEPASSWORD" || command == "REGISTER") {
 		wxLogMessage(_T("sent: %s ... <password removed>"), TowxString(command).c_str());
 		return;
 	}
@@ -1733,7 +1750,6 @@ void TASServer::RemoveBot(int battleid, User& bot)
 	}
 
 	IBattle& battle = GetBattle(battleid);
-	ASSERT_LOGIC(&bot != 0, "Bot does not exist.");
 
 	if (!(battle.IsFounderMe() || (bot.BattleStatus().owner == GetMe().GetNick()))) {
 		DoActionBattle(battleid, "thinks the bot " + bot.GetNick() + " should be removed.");
@@ -1782,6 +1798,9 @@ void TASServer::OnDisconnected(wxSocketError err)
 	m_relay_host_manager_list.clear();
 	m_last_id = 0;
 	m_pinglist.clear();
+	m_do_register = false;
+	m_server_lanmode = false;
+	m_supported_spring_version.clear();
 	if (m_se != NULL) {
 		IServer::Reset();
 		m_se->OnDisconnected(connectionwaspresent);
@@ -2024,3 +2043,10 @@ bool TASServer::IsCurrentBattle(int battle_id)
 	}
 	return true;
 }
+
+void TASServer::OnInvalidFingerprintReceived(const std::string& fingerprint)
+{
+	const std::string expected_fingerprint = sett().GetServerFingerprint(GetServerName());
+	m_se->OnInvalidFingerprintReceived(fingerprint, expected_fingerprint);
+}
+
